@@ -73,10 +73,10 @@ def logentry(entry):
     - response_size: HTTP response size, this will be casted to 'int'.
     - referer: Referer header. if "-" is given, that will be ignored.
 
-    If error response_status was detedted, its access time and request path
-    is reported via logger. and retured entry includes error key.
+    If error response_status was detected, its access time and request path
+    is reported via logger. And retured entry includes error key.
 
-    And, "request_query" will be added if "request_path" has query string.
+    "request_query" will be added if "request_path" has query string.
     Note that this is key/values mapping even if values have one element.
 
     :param entry: regex parsed object
@@ -91,8 +91,8 @@ def logentry(entry):
     if entry['response_status']:
         s = int(entry['response_status'])
         if s >= 400:
-            logging.info("Error response was detected: %s at [%s]",
-                        entry['request_path'], entry['access_time'])
+            logging.info("Error response [%d] was detected: %s at [%s]",
+                        s, entry['request_path'], entry['access_time'])
             entry['error_%d' % (s,)] = entry['request_path']
     if entry['response_size'] == '-':  # Apache internal dummy connection
         entry['response_size'] = None
